@@ -25,7 +25,6 @@
 #include <QSharedData>
 #include <QStandardPaths>
 #include <QTextStream>
-#include <QUrl>
 
 #include <algorithm>
 
@@ -278,10 +277,10 @@ QString KAboutLicense::text() const
     case KAboutLicense::BSD_3_Clause:
     case KAboutLicense::CC0_V1:
     case KAboutLicense::MPL_V2:
-        knownLicense = true;
-        result += QCoreApplication::translate("KAboutLicense", "This program is distributed under the terms of the %1.").arg(name(KAboutLicense::ShortName))
-            + u"\n\n"_s
-            + QCoreApplication::translate("KAboutLicense", "You can find the full term <a href=\"https://spdx.org/licenses/%1.html\">the SPDX website</a>")
+        result +=
+            QCoreApplication::translate("KAboutLicense", "<p>This program is distributed under the terms of the %1.</p>").arg(name(KAboutLicense::ShortName))
+            + QCoreApplication::translate("KAboutLicense",
+                                          "<p>You can find the full terms on <a href=\"https://spdx.org/licenses/%1.html\">the SPDX website</a>.</p>")
                   .arg(d->spdxID());
         break;
     case KAboutLicense::Custom:
@@ -398,11 +397,11 @@ QString KAboutLicense::name(KAboutLicense::NameFormat formatName) const
     case KAboutLicense::BSD_3_Clause:
         licenseShort = QCoreApplication::translate("KAboutLicense", "BSD-3-Clause", "@item license (short name)");
         licenseFull = QCoreApplication::translate("KAboutLicense", "BSD 3-Clause \"New\" or \"Revised\" License", "@item license");
+        break;
     case KAboutLicense::MPL_V2:
         licenseShort = QCoreApplication::translate("KAboutLicense", "MPL 2.0", "@item license (short name)");
         licenseFull = QCoreApplication::translate("KAboutLicense", "Mozilla Public License 2.0", "@item license");
         break;
-        break;
     case KAboutLicense::Custom:
     case KAboutLicense::File:
         licenseShort = licenseFull = QCoreApplication::translate("KAboutLicense", "Custom", "@item license");
@@ -1199,6 +1198,10 @@ void KAboutData::setApplicationData(const KAboutData &aboutData)
     // Options are to remove the overlapping properties of KAboutData for cleancode, or making the
     // overlapping properties official shadow properties of their Q*Application countparts, though
     // that increases behavioural complexity a little.
+
+    if (KAboutDataListener::s_theListener) {
+        Q_EMIT KAboutDataListener::s_theListener->applicationDataChanged();
+    }
 }
 
 // only for KCrash (no memory allocation allowed)
@@ -1274,4 +1277,14 @@ void KAboutData::processCommandLine(QCommandLineParser *parser)
     }
 }
 
+std::unique_ptr<KAboutDataListener> KAboutDataListener::s_theListener = nullptr;
+
+KAboutDataListener *KAboutDataListener::instance()
+{
+    if (!s_theListener) {
+        s_theListener = std::make_unique<KAboutDataListener>();
+    }
+    return s_theListener.get();
+}
+
 #include "moc_kaboutdata.cpp"
